# (C) Copyright 2021 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#

from .bbox import BoundingBoxNormaliser
from .date import DateListNormaliser
from .parameter import ParameterNormaliser

NORMALISERS = {
    "date-list": DateListNormaliser,
    "parameter-list": ParameterNormaliser,
    "bounding-box": BoundingBoxNormaliser,
}
